( cd usr/lib/alsa-lib ; rm -rf libasound_module_rate_samplerate_best.so )
( cd usr/lib/alsa-lib ; ln -sf libasound_module_rate_samplerate.so libasound_module_rate_samplerate_best.so )
( cd usr/lib/alsa-lib ; rm -rf libasound_module_rate_samplerate_medium.so )
( cd usr/lib/alsa-lib ; ln -sf libasound_module_rate_samplerate.so libasound_module_rate_samplerate_medium.so )
( cd usr/lib/alsa-lib ; rm -rf libasound_module_rate_speexrate_medium.so )
( cd usr/lib/alsa-lib ; ln -sf libasound_module_rate_speexrate.so libasound_module_rate_speexrate_medium.so )
( cd usr/lib/alsa-lib ; rm -rf libasound_module_rate_samplerate_linear.so )
( cd usr/lib/alsa-lib ; ln -sf libasound_module_rate_samplerate.so libasound_module_rate_samplerate_linear.so )
( cd usr/lib/alsa-lib ; rm -rf libasound_module_rate_lavcrate_high.so )
( cd usr/lib/alsa-lib ; ln -sf libasound_module_rate_lavcrate.so libasound_module_rate_lavcrate_high.so )
( cd usr/lib/alsa-lib ; rm -rf libasound_module_rate_speexrate_best.so )
( cd usr/lib/alsa-lib ; ln -sf libasound_module_rate_speexrate.so libasound_module_rate_speexrate_best.so )
( cd usr/lib/alsa-lib ; rm -rf libasound_module_rate_samplerate_order.so )
( cd usr/lib/alsa-lib ; ln -sf libasound_module_rate_samplerate.so libasound_module_rate_samplerate_order.so )
( cd usr/lib/alsa-lib ; rm -rf libasound_module_rate_lavcrate_faster.so )
( cd usr/lib/alsa-lib ; ln -sf libasound_module_rate_lavcrate.so libasound_module_rate_lavcrate_faster.so )
( cd usr/lib/alsa-lib ; rm -rf libasound_module_rate_lavcrate_higher.so )
( cd usr/lib/alsa-lib ; ln -sf libasound_module_rate_lavcrate.so libasound_module_rate_lavcrate_higher.so )
( cd usr/lib/alsa-lib ; rm -rf libasound_module_rate_lavcrate_fast.so )
( cd usr/lib/alsa-lib ; ln -sf libasound_module_rate_lavcrate.so libasound_module_rate_lavcrate_fast.so )

#!/bin/sh
ldconfig -r .

function install_file() {
  # $1 = File to process

  FILE="$(dirname "$1")/$(basename "$1" .new)"
  if [ ! -e "$FILE" ]
  then
    mv "$FILE.new" "$FILE"
  elif [ "$(cat "$FILE" | md5sum)" != "$(cat "$FILE.new" | md5sum)" ]
  then
    #     |--------|--------------------------------------------------|
    echo "WARNING: $FILE has been customised."
    echo "         Examine the $FILE.new file"
    echo "         and integrate any changes into the custom file."
    echo
  else
    rm -f "$FILE.new"
  fi
}

install_file etc/asound.conf.new
